<?php

namespace Drupal\bynder;

use Symfony\Component\HttpFoundation\Request;

/**
 * Provides Drupal 8 Bynder API.
 *
 * @package Drupal\bynder
 */
interface BynderApiInterface {

  /**
   * Gets an instance of the asset bank manager to use for DAM queries.
   *
   * @return \Bynder\Api\IAssetBankManager
   *   An instance of the asset bank manager using the request handler.
   */
  public function getAssetBankManager();

  /**
   * Initiates the access token retrieval.
   *
   * Gets request token from Bynder and prepares everything to redirect user to
   * Bynder for login.
   *
   * @see ::finishOAuthTokenRetrieval()
   *
   * @return \Drupal\Core\Url
   *   Url to redirect the user to.
   */
  public function initiateOAuthTokenRetrieval();

  /**
   * Finishes the access token retrieval after the user has been redirected.
   *
   * When Bynder redirects the user back after the successful login this
   * function takes over and gets the access token and stores it for the future
   * use.
   *
   * @param Request $request
   *   The current request.
   */
  public function finishOAuthTokenRetrieval(Request $request);

  /**
   * Gets if the current user has a valid oAuth access token.
   *
   * @return bool
   *   TRUE if the current user has a valid oAuth access token. FALSE otherwise.
   */
  public function hasAccessToken();

}
