<?php

namespace Drupal\bynder_test_module;

use Drupal\bynder\BynderApi;
use Drupal\Core\Config\ConfigFactoryInterface;
use Drupal\Core\Logger\LoggerChannelFactoryInterface;
use Drupal\Core\State\StateInterface;
use Symfony\Component\HttpFoundation\Session\SessionInterface;
use GuzzleHttp\Exception\RequestException;
use GuzzleHttp\Psr7\Request;

/**
 * Bynder API test service.
 *
 * @package Drupal\bynder
 */
class BynderApiTest extends BynderApi {

  /**
   * Returns the defined value.
   */
  public function getBrands() {
    if ($brands = $this->state->get('bynder.bynder_test_brands')) {
      return $brands;
    }

    throw new RequestException('Test', new Request('test', 'test'));
  }

  /**
   * Returns value set in state.
   *
   * @param string $media_uuid
   *   The media UUID.
   *
   * @return mixed
   *   Returns what is set in the state.
   */
  public function getMediaInfo($media_uuid) {
    return $this->state->get('bynder.bynder_test_media_info');
  }

  /**
   * Returns value set in state.
   *
   * @param array $query
   *   Search query.
   *
   * @return mixed
   *   Returns what is set in the state.
   *
   * @throws \Exception
   *   Connection fails.
   */
  public function getMediaList(array $query) {
    if (!($media_list = $this->state->get('bynder.bynder_test_media_list'))) {
      throw new \Exception();
    }

    // Filter on keyword.
    if (!empty($query['keyword'])) {
      foreach ($media_list['media'] as $key => $media) {
        if ($query['keyword'] != $media['keyword']) {
          unset($media_list['media'][$key]);
        }
      };
    }

    // Filter on meta-property options.
    if (!empty($query['propertyOptionId'])) {
      $options = explode(',', $query['propertyOptionId']);
      foreach ($media_list['media'] as $key => $media) {
        if (empty(array_intersect($options, $media['propertyOptions']))) {
          unset($media_list['media'][$key]);
        }
      };
    }

    // Filter on tags.
    if (!empty($query['tags'])) {
      foreach ($media_list['media'] as $key => $media) {
        if (!in_array($query['tags'], $media['tags'])) {
          unset($media_list['media'][$key]);
        }
      };
    }

    return $media_list;
  }

  /**
   * Returns value set in state.
   */
  public function getMetaproperties() {
    if (!$this->state->get('bynder.bynder_test_metaproperties')) {
      throw new \Exception();
    }
    return $this->state->get('bynder.bynder_test_metaproperties');
  }

  /**
   * Returns value set in state.
   */
  public function hasAccessToken() {
    if (!$this->state->get('bynder.bynder_test_access_token')) {
      return FALSE;
    }
    return TRUE;
  }

  /**
   * Returns value set in state.
   */
  public function getTags() {
    if (!$this->state->get('bynder.bynder_test_tags')) {
      throw new \Exception();
    }
    return $this->state->get('bynder.bynder_test_tags');
  }

  /**
   * Returns value set in state.
   *
   * @param string $media_uuid
   *   The media UUID.
   *
   * @return array
   *   Returns array of expected values.
   */
  public function uploadFileAsync($media_uuid) {
    return [
      'success' => $this->state->get('bynder.bynder_test_upload_success'),
      'mediaid' => $this->state->get('bynder.bynder_test_upload_mediaid'),
    ];
  }

  /**
   * Simulate deleting media and returns void.
   *
   * @param string $media_uuid
   *   The media UUID.
   */
  public function deleteMedia($media_uuid) {}

}
